﻿using GalaSoft.MvvmLight.Messaging;
using System.Collections.Generic;
using Xamarin.Forms;
using XFScan.Messages;
using ZXing.Mobile;
using ZXing.Net.Mobile.Forms;

namespace XFScan.Views
{
    public partial class MainPage : ContentPage
    {
        protected ZXing.Result previousQRCode { get; set; }
        public MainPage()
        {
            InitializeComponent();

            Messenger.Default.Register<QRScanRequest>(this, QRScanCallBack);
        }

        private void Button_Clicked(object sender, System.EventArgs e)
        {
            Messenger.Default.Send<QRScanRequest>(new QRScanRequest());
        }

        private async void QRScanCallBack(QRScanRequest request)
        {
            var options = new MobileBarcodeScanningOptions
            {
                AutoRotate = false,
                UseFrontCameraIfAvailable = false,
                TryHarder = true,
                PossibleFormats = new List<ZXing.BarcodeFormat>
                {
                    ZXing.BarcodeFormat.QR_CODE
                }
            };

            // Generate barcode scan page.
            var scanPage = new ZXingScannerPage(options);

                scanPage.Title = "Target the QRCode"; 
                
                scanPage.OnScanResult += (result) =>
                {
                    // Stop scan.
                    scanPage.IsScanning = false;

                    if ((previousQRCode == null) || (!(previousQRCode.Text.Equals(result.Text))))
                    {
                        previousQRCode = result;

                        // Scan result management.
                        Device.BeginInvokeOnMainThread(() =>
                        {
                            try
                            {
                                Navigation.PopAsync();

                                // Check the value to see if they match the original byte stream.
                                byte[] dataStream = System.Text.Encoding.GetEncoding("ISO-8859-1").GetBytes(result.Text); // formerly System.Text.Encoding.UTF8.GetBytes(dataMessage.Message.Text);
                                var temp = result.ResultMetadata[ZXing.ResultMetadataType.BYTE_SEGMENTS]; //

                                //DisplayAlert("Scanned Barcode", result.Text, "OK");
                        }
                            catch (System.Exception ex)
                            {
                                throw ex;
                            }
                        });
                    }
                };

            // Push barcode scan page.
            await Navigation.PushAsync(scanPage);
        }
    }
}
